var Util = require('/shared/mbanking/utils/util');
var Styles = require('/shared/mbanking/modules/styles.mod');
var NavEngine = require('/shared/mbanking/ui/nav/NavEngine');

var NATIVE_EXTENSION_PACKAGEID = "com.mfoundry.mb.helloworld";
var NATIVE_EXTENSION_RESOURCE_IMAGE_PATH = "/com.mfoundry.mb.helloworld_world.png";

// This event is fired when the user interaction with this page or subpages have completed and the user is about to be
// navigated back to the originating caller.
var NAVTARG_RESP_EVENT = "com.mfoundry.mb.helloworld:navtarget_resp"

function HWNavTarget(controller, data) {
	Util.info('HWNavTarget constructor, data: ' + JSON.stringify(data));
	this._nullifyLocals();
    this.controller = controller;
	this.constructionData = data || undefined;
    this._createTiView();
}

HWNavTarget.prototype = {

	/**
	 * @override
	 */
	getTiView: function() {
		if (this.tiView === null) {
			this._createTiView();
		}
		return this.tiView;
	},

	/**
	 * @override
	 */
	cleanUp: function() {
		this._nullifyLocals();
	},

	/**
	 * @override
	 */
	navigatedTo: function(navEngine, fromTargetId, data) {
		Util.info('navigated to HWNavTarget from targetId: ' +
				  fromTargetId + ', data: ' + JSON.stringify(data));

		this.dataFromNav = data;
		this._updatePage();
	},

	navigatingFrom: function(navEngine, toTargetId, direction, toRootId) {
		Util.info('navigating from to targetId' + toTargetId +
				  ', direction: ' + direction + ', to rootdId: ' + toRootId);

		// If the user has navigated back via the [back] button, then signal to the caller that the response is
		// undefined. We do this mainly to tell the caller to release their event handler on a top-level app event.
		if (direction === 'back' && !this.sentResp) {
			Util.info('sending clearing event');
			Ti.App.fireEvent(NAVTARG_RESP_EVENT, {
				originId: this.dataFromNav.originId || undefined,
				status: 'success',
				message: undefined
			});
		}

		return true;
	},

	//------------------------------------------------------------------------------------------------------------------
	// Privates
	//------------------------------------------------------------------------------------------------------------------

	_nullifyLocals: function() {
		this.constructionData = null;
		this.dataFromNav = null;
		this.tiView = null;
		this.txtFldRecv = null;
		this.txtFldSend = null;
		this.sentResp = false;
	},

	_createTiView: function() {
		var that = this;

		this.tiView = Ti.UI.createView({
			backgroundColor:Styles.S('BACKGROUND_COLOR', NATIVE_EXTENSION_PACKAGEID),
			top: 0,
			layout: 'vertical'
		});

		this.tiView.add(this._createLabel('Received:'));

		this.tiView.add(
			this.txtFldRecv = Ti.UI.createTextField({
				top: 10,
				left: 20,
				right: 20,
				height: 35,
				font: { fontSize: 14, fontWeight: 'normal' },
				color: 'black',
				backgroundColor: 'white',
				paddingLeft: 10,
				paddingRight: 10,
				borderRadius: 10,
				hintText: 'Received nothing',
				editable: false
			}));

		this.tiView.add(this._createLabel('Send back to caller:'));

		this.tiView.add(
			this.txtFldSend = Ti.UI.createTextField({
				top: 10,
				left: 20,
				right: 20,
				height: 35,
				font: { fontSize: 14, fontWeight: 'normal' },
				color: 'black',
				backgroundColor: 'white',
				paddingLeft: 10,
				paddingRight: 10,
				borderRadius: 10,
				hintText: 'Send back what?',
				returnKeyType: Ti.UI.RETURNKEY_DONE
			}));

		this.txtFldSend.addEventListener('return', function(e) {
			that._btnDone_onSingleTap();
		});

		var btnDone = Ti.UI.createButton({
			top: 10,
			left: 20,
			right: 20,
			height: 'size',
			title: 'Done',
			font: { fontSize: 18, fontWeight: 'bold' },
			color: 'red'
		});
		this.tiView.add(btnDone);

		btnDone.addEventListener('singletap', function(e) {
			that._btnDone_onSingleTap(e);
		});
	},

	_btnDone_onSingleTap: function(e) {
		var resp = this.txtFldSend.value.trim();
		resp = resp !== null && resp.length > 0 ? resp : undefined;
		Ti.App.fireEvent(NAVTARG_RESP_EVENT, {
			originId: this.dataFromNav.originId || undefined,
			status: 'success',
			message: resp
		});
		this.sentResp = true;
		setTimeout(function() {NavEngine.getInstance().navigateBack();}, 250);
	},

	_createLabel: function(labelText) {
		return label = Ti.UI.createLabel({
			text: labelText,
			font:Styles.S('SIGON_LARGE_BOLD_TEXT_FONT', NATIVE_EXTENSION_PACKAGEID),
			color:Styles.S('SECONDARY_TEXT_COLOR', NATIVE_EXTENSION_PACKAGEID),
			shadowColor:"#000000",
			shadowOffset:{"x":0,"y":-1},
			textAlign:Ti.UI.TEXT_ALIGNMENT_CENTER,
			left:20,
			top:10,
			height: Ti.UI.SIZE
		});
	},

	_updatePage: function() {
		if (this._receivedMsg()) {
			this.txtFldRecv.value = this._receivedMsg();
		}
	},

	_receivedMsg: function() {
		return this.dataFromNav && this.dataFromNav.message ? this.dataFromNav.message : undefined
	}
}

// EXPORTS
module.exports = HWNavTarget;
