 
//Requires
var Lang = require('/shared/mbanking/modules/langmain.mod');
var Styles = require('/shared/mbanking/modules/styles.mod');
var Util = require('/shared/mbanking/utils/util');
var Config = require('/shared/mbanking/modules/config.mod');
var Resources = require('/shared/mbanking/modules/resources.mod');
var NativeExtensionServiceUtils = require('/shared/mbanking/utils/NativeExtensionServiceUtils');

var NATIVE_EXTENSION_PACKAGEID = "com.mfoundry.mb.helloworld";
var NATIVE_EXTENSION_RESOURCE_IMAGE_PATH = "/com.mfoundry.mb.helloworld_world.png";

function UIComponentTestPage(controller, data) {
	this.navToData = null;

    this.controller = controller;
    this.tiView = this._createTiView();

}
// REQUIRED FUNCTIONS
UIComponentTestPage.prototype.getTiView = function(){
     
    // The following would work IF view creation didn't depend on any data
    if (this.tiView == null) {
        this.tiView = this._createTiView();
     }
    return this.tiView;
}
// Cleanup
UIComponentTestPage.prototype.cleanUp = function() {
    //Set to 'null' any references
    this.tiView = null;
    this.controller = null;
}

// INTERNAL FUNCTIONS
//View creation
UIComponentTestPage.prototype._createTiView = function(){

    var tiView = Ti.UI.createView({
        backgroundColor:Styles.S('BACKGROUND_COLOR', NATIVE_EXTENSION_PACKAGEID),
        top: 0
    });
     
    var scrollView = this._createScrollView();
	this.scrollView = scrollView;
    scrollView.add(this._createTitle(Lang.L('This is a test of the Native Extension UI Component')));
    
    //this tests the NE's ability to pull an image resource file
    var sampleImage = this._createImage();
    if (sampleImage != null) {
    		scrollView.add(sampleImage);
    }
	
	var langString = Lang.L("com_mfoundry_mb_helloworld_lang_sample");   
	scrollView.add(this._createLabel(langString));
	var productInfo	=NativeExtensionServiceUtils.getProductInfo("com.mfoundry.mb.helloworld");
	if (productInfo) {
		scrollView.add(this._createLabel(productInfo.name));	
		scrollView.add(this._createLabel(productInfo.version));	
		scrollView.add(this._createLabel(productInfo.copyright));	
	}
	
	tiView.add(scrollView);

	this._createHtml5ExtContainer();
     
    return tiView;
}

UIComponentTestPage.prototype._createScrollView = function() {
    var scrollView = Ti.UI.createScrollView({
        backgroundColor: 'transparent',
        top: 0,
        contentHeight: 'auto',
        layout: 'vertical'
    });
     
    return scrollView;
}

UIComponentTestPage.prototype._createTitle = function(title) {
	return this._createLabel(title);
}


UIComponentTestPage.prototype._createImage = function() {
	var retval = null;
 	var imageUrl = Resources.imageUrl(NATIVE_EXTENSION_RESOURCE_IMAGE_PATH);
	if (imageUrl != null) {
		retval = Ti.UI.createImageView({
			image:imageUrl
		});		
	}
	return retval;
}

UIComponentTestPage.prototype._createLabel = function(labelText) {
	return label = Ti.UI.createLabel({
        text: labelText,
        font:Styles.S('SIGON_LARGE_BOLD_TEXT_FONT', NATIVE_EXTENSION_PACKAGEID),
        color:Styles.S('SECONDARY_TEXT_COLOR', NATIVE_EXTENSION_PACKAGEID),
        shadowColor:"#000000",
        shadowOffset:{"x":0,"y":-1},
        textAlign:Ti.UI.TEXT_ALIGNMENT_CENTER,
        left:20,
        right: 20,
        top:10,
        height: Ti.UI.SIZE
    });    
}

UIComponentTestPage.prototype._createHtml5ExtContainer = function() {
	this.html5ExtContainer = Ti.UI.createView({
		width: Ti.UI.FILL,
		height: Ti.UI.SIZE,
		layout: 'vertical',
		backgroundColor: 'transparent'
	});

	var lbl = this._createLabel('Received:');
	lbl.textAlign = Ti.UI.TEXT_ALIGNMENT_LEFT;
	this.html5ExtContainer.add(lbl);

	this.txtFldRecv = Ti.UI.createTextField({
		top: 10,
		left: 20,
		right: 20,
		height: 35,
		font: { fontSize: 14, fontWeight: 'normal' },
		color: 'black',
		backgroundColor: 'white',
		paddingLeft: 10,
		paddingRight: 10,
		borderRadius: 10,
		hintText: 'Received nothing',
		editable: false
	});
	this.html5ExtContainer.add(this.txtFldRecv);
}

UIComponentTestPage.prototype.navigatedTo = function(navEngine, fromTargetId, data) {
	Util.info('navigatedTo from targetId: ' + fromTargetId + ', data: ' + JSON.stringify(data));
	this.navToData = data;
	this._isFromFinx() ? this._updateHtml5ExtPage() : this._updateGnmPage();
}

UIComponentTestPage.prototype._updateGnmPage = function() {
	this.scrollView.remove(this.html5ExtContainer);
}

UIComponentTestPage.prototype._updateHtml5ExtPage = function() {
	this.scrollView.add(this.html5ExtContainer);
	this.txtFldRecv.value = this._receivedMsg() || null;
}

UIComponentTestPage.prototype._receivedMsg = function() {
	return this.navToData && this.navToData.message ? this.navToData.message : undefined;
}

UIComponentTestPage.prototype._isFromFinx = function() {
	return this.navToData && this.navToData.originId && this.navToData.originId.indexOf('finx') !== -1;
}

// EXPORTS
module.exports = UIComponentTestPage;
